@@ -20,18 +20,7 @@
 
 import sys
 
-from PyQt4 import QtCore, QtGui
-
-try:
-    from PyQt4 import QAxContainer
-except ImportError:
-    app = QtGui.QApplication(sys.argv)
-    QtGui.QMessageBox.critical(None, "Web browser",
-            "The Windows commercial version of PyQt is required to run this "
-                    "example.",
-            QtGui.QMessageBox.Ok | QtGui.QMessageBox.Default,
-            QtGui.QMessageBox.NoButton)
-    sys.exit(1)
+from PyQt4 import QtCore, QtGui, QAxContainer
 
 from ui_mainwindow import Ui_MainWindow
 
@@ -57,19 +46,25 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
         self.tbAddress.insertWidget(self.actionGo, self.addressEdit)
 
         self.addressEdit.returnPressed.connect(self.actionGo.trigger)
-        self.actionBack.triggered.connect(self.WebBrowser.GoBack)
-        self.actionForward.triggered.connect(self.WebBrowser.GoForward)
-        self.actionStop.triggered.connect(self.WebBrowser.Stop)
-        self.actionRefresh.triggered.connect(self.WebBrowser.Refresh)
-        self.actionHome.triggered.connect(self.WebBrowser.GoHome)
-        self.actionSearch.triggered.connect(self.WebBrowser.GoSearch)
+        QtCore.QObject.connect(self.actionBack, QtCore.SIGNAL('triggered()'),
+                self.WebBrowser, QtCore.SLOT('GoBack()'))
+        QtCore.QObject.connect(self.actionForward, QtCore.SIGNAL('triggered()'),
+                self.WebBrowser, QtCore.SLOT('GoForward()'))
+        QtCore.QObject.connect(self.actionStop, QtCore.SIGNAL('triggered()'),
+                self.WebBrowser, QtCore.SLOT('Stop()'))
+        QtCore.QObject.connect(self.actionRefresh, QtCore.SIGNAL('triggered()'),
+                self.WebBrowser, QtCore.SLOT('Refresh()'))
+        QtCore.QObject.connect(self.actionHome, QtCore.SIGNAL('triggered()'),
+                self.WebBrowser, QtCore.SLOT('GoHome()'))
+        QtCore.QObject.connect(self.actionSearch, QtCore.SIGNAL('triggered()'),
+                self.WebBrowser, QtCore.SLOT('GoSearch()'))
 
         self.pb = QtGui.QProgressBar(self.statusBar())
         self.pb.setTextVisible(False)
         self.pb.hide()
         self.statusBar().addPermanentWidget(self.pb)
 
-        self.WebBrowser.dynamicCall("GoHome()")
+        self.WebBrowser.dynamicCall('GoHome()')
 
     def closeEvent(self, e):
         MainWindow._window_list.remove(self)
@@ -101,7 +96,7 @@ class MainWindow(QtGui.QMainWindow, Ui_MainWindow):
 
     @QtCore.pyqtSlot()
     def on_actionGo_triggered(self):
-        self.WebBrowser.dynamicCall("Navigate(const QString&)",
+        self.WebBrowser.dynamicCall('Navigate(const QString&)',
                 QtCore.QVariant(self.addressEdit.text()))
 
     @QtCore.pyqtSlot()
