@@ -42,6 +42,7 @@ class PieView(QtGui.QAbstractItemView):
         self.pieSize = self.totalSize - 2*self.margin
         self.validItems = 0
         self.totalValue = 0.0
+        self.origin = QtCore.QPoint()
         self.rubberBand = None
 
     def dataChanged(self, topLeft, bottomRight):
@@ -197,16 +198,16 @@ class PieView(QtGui.QAbstractItemView):
     def mousePressEvent(self, event):
         super(PieView, self).mousePressEvent(event)
 
-        origin = event.pos()
+        self.origin = event.pos()
         if not self.rubberBand:
             self.rubberBand = QtGui.QRubberBand(QtGui.QRubberBand.Rectangle,
                     self)
-        self.rubberBand.setGeometry(QtCore.QRect(origin, QtCore.QSize()))
+        self.rubberBand.setGeometry(QtCore.QRect(self.origin, QtCore.QSize()))
         self.rubberBand.show()
 
     def mouseMoveEvent(self, event):
         if self.rubberBand:
-            self.rubberBand.setGeometry(QtCore.QRect(origin, event.pos()).normalized())
+            self.rubberBand.setGeometry(QtCore.QRect(self.origin, event.pos()).normalized())
 
         super(PieView, self).mouseMoveEvent(event)
 
