@@ -209,8 +209,8 @@ _qwidgets = (
     "QRadioButton", 
     "QScrollArea", "QScrollBar", "QSlider", "QSpinBox", "QSplitter",
     "QStackedWidget", "QStatusBar",
-    "QTableView", "QTextBrowser", "QTextEdit", "QTimeEdit", "QToolBar",
-    "QToolButton", "QTreeView",
+    "QTextBrowser", "QTextEdit", "QTimeEdit", "QToolBar",
+    "QToolButton",
     "QWizard", "QWizardPage")
 
 class QtGui(ProxyNamespace):
@@ -248,6 +248,8 @@ class QtGui(ProxyNamespace):
             sp._uic_name = "%s.sizePolicy()" % self
             return sp
 
+    class QHeaderView(ProxyClass): pass
+
     class QListWidgetItem(ProxyClass): pass
 
     class QListWidget(QWidget):
@@ -258,12 +260,17 @@ class QtGui(ProxyNamespace):
             return QtGui.QListWidgetItem("%s.item(%i)" % (self, row), False,
                     (), noInstantiation=True)
 
+    class QTreeView(QWidget):
+        def header(self):
+            return QtGui.QHeaderView("%s.header()" % self,
+                    False, (), noInstantiation=True)
+
     class QTreeWidgetItem(ProxyClass):
         def child(self, index):
             return QtGui.QTreeWidgetItem("%s.child(%i)" % (self, index),
                     False, (), noInstantiation=True)
 
-    class QTreeWidget(QWidget):
+    class QTreeWidget(QTreeView):
         isSortingEnabled = i18n_func("isSortingEnabled")
         setSortingEnabled = i18n_void_func("setSortingEnabled")
 
@@ -275,9 +282,18 @@ class QtGui(ProxyNamespace):
             return QtGui.QTreeWidgetItem("%s.topLevelItem(%i)" % (self, index),
                     False, (), noInstantiation=True)
 
+    class QTableView(QWidget):
+        def horizontalHeader(self):
+            return QtGui.QHeaderView("%s.horizontalHeader()" % self,
+                    False, (), noInstantiation=True)
+
+        def verticalHeader(self):
+            return QtGui.QHeaderView("%s.verticalHeader()" % self,
+                    False, (), noInstantiation=True)
+
     class QTableWidgetItem(ProxyClass): pass
 
-    class QTableWidget(QWidget):
+    class QTableWidget(QTableView):
         isSortingEnabled = i18n_func("isSortingEnabled")
         setSortingEnabled = i18n_void_func("setSortingEnabled")
 
