@@ -154,7 +154,8 @@ class UIParser(object):
         
         parent = self.stack.topwidget
         if isinstance(parent, (QtGui.QToolBox, QtGui.QTabWidget,
-                               QtGui.QStackedWidget, QtGui.QDockWidget)):
+                               QtGui.QStackedWidget, QtGui.QDockWidget,
+                               QtGui.QWizard)):
             parent = None
         
         
@@ -167,6 +168,15 @@ class UIParser(object):
         self.traverseWidgetTree(elem)
         widget = self.stack.popWidget()
 
+        if isinstance(widget, QtGui.QTreeView):
+            self.handleHeaderView(elem, "header", widget.header())
+
+        elif isinstance(widget, QtGui.QTableView):
+            self.handleHeaderView(elem, "horizontalHeader",
+                    widget.horizontalHeader())
+            self.handleHeaderView(elem, "verticalHeader",
+                    widget.verticalHeader())
+
         if self.sorting_enabled is not None:
             widget.setSortingEnabled(self.sorting_enabled)
             self.sorting_enabled = None
@@ -209,6 +219,9 @@ class UIParser(object):
             if tooltip is not None:
                 topwidget.setTabToolTip(topwidget.indexOf(widget), tooltip)
             
+        elif isinstance(topwidget, QtGui.QWizard):
+            topwidget.addPage(widget)
+            
         elif isinstance(topwidget, QtGui.QStackedWidget):
             topwidget.addWidget(widget)
             
@@ -245,21 +258,66 @@ class UIParser(object):
                 topwidget.addDockWidget(QtCore.Qt.DockWidgetArea(dwArea),
                         widget)
 
+    def handleHeaderView(self, elem, name, header):
+        value = self.wprops.getAttribute(elem, name + "Visible")
+        if value is not None:
+            header.setVisible(value)
+
+        value = self.wprops.getAttribute(elem, name + "CascadingSectionResizes")
+        if value is not None:
+            header.setCascadingSectionResizes(value)
+
+        value = self.wprops.getAttribute(elem, name + "DefaultSectionSize")
+        if value is not None:
+            header.setDefaultSectionSize(value)
+
+        value = self.wprops.getAttribute(elem, name + "HighlightSections")
+        if value is not None:
+            header.setHighlightSections(value)
+
+        value = self.wprops.getAttribute(elem, name + "MinimumSectionSize")
+        if value is not None:
+            header.setMinimumSectionSize(value)
+
+        value = self.wprops.getAttribute(elem, name + "ShowSortIndicator")
+        if value is not None:
+            header.setShowSortIndicator(value)
+
+        value = self.wprops.getAttribute(elem, name + "StretchLastSection")
+        if value is not None:
+            header.setStretchLastSection(value)
+
     def createSpacer(self, elem):
         width = int(elem.findtext("property/size/width"))
         height = int(elem.findtext("property/size/height"))
+
         sizeType = self.wprops.getProperty(elem, "sizeType")
         if sizeType is None:
             sizeType = "QSizePolicy::Expanding"
+
         policy = (QtGui.QSizePolicy.Minimum,
                   getattr(QtGui.QSizePolicy, sizeType.split("::")[-1]))
+
         if self.wprops.getProperty(elem, "orientation") == "Qt::Horizontal":
             policy = policy[1], policy[0]
-        spacer = self.factory.createQObject("QSpacerItem", self.uniqueName("spacerItem"),
-                                       (width, height) + policy,
-                                        is_attribute = False)
+
+        spacer = self.factory.createQObject("QSpacerItem",
+                self.uniqueName("spacerItem"), (width, height) + policy,
+                is_attribute=False)
+
         if self.stack.topIsLayout():
-            self.stack.peek().addItem(spacer, *elem.attrib["grid-position"])
+            lay = self.stack.peek()
+            gp = elem.attrib["grid-position"]
+
+            if isinstance(lay, QtGui.QFormLayout):
+                if gp[1]:
+                    role = QtGui.QFormLayout.FieldRole
+                else:
+                    role = QtGui.QFormLayout.LabelRole
+
+                lay.setItem(gp[0], role, spacer)
+            else:
+                lay.addItem(spacer, *gp)
 
     def createLayout(self, elem):
         # Qt v4.3 introduced setContentsMargins() and separate values for each
@@ -337,7 +395,21 @@ class UIParser(object):
 
                 top_layout.setLayout(gp[0], role, layout)
             else:
+                stretch = elem.attrib.get('stretch')
+                if stretch:
+                    for idx, value in enumerate(stretch.split(',')):
+                        value = int(value)
+                        if value > 0:
+                            layout.setStretch(idx, value)
+
                 top_layout.addLayout(layout, *gp)
+        else:
+            stretch = elem.attrib.get('stretch')
+            if stretch:
+                for idx, value in enumerate(stretch.split(',')):
+                    value = int(value)
+                    if value > 0:
+                        layout.setStretch(idx, value)
 
     def handleItem(self, elem):
         if self.stack.topIsLayout():
@@ -387,8 +459,8 @@ class UIParser(object):
                     parent = w
                     nr_in_root = self.item_nr
 
-                item = self.factory.createQObject("QTreeWidgetItem", "item",
-                        (parent, ), False)
+                item = self.factory.createQObject("QTreeWidgetItem",
+                        "item_%d" % len(self.itemstack), (parent, ), False)
 
                 if self.item_nr == 0 and not self.itemstack:
                     self.sorting_enabled = self.factory.invoke("__sortingEnabled", w.isSortingEnabled)
@@ -595,13 +667,13 @@ class UIParser(object):
         self.defaults["spacing"] = int(elem.attrib["spacing"])
 
     def setTaborder(self, elem):
-        try:
-            lastwidget = getattr(self.toplevelWidget, elem[0].text)
-        except IndexError:
-            return
-        for widget in iter(elem[1:]):
-            widget = getattr(self.toplevelWidget, widget.text)
-            self.toplevelWidget.setTabOrder(lastwidget, widget)
+        lastwidget = None
+        for widget_elem in elem:
+            widget = getattr(self.toplevelWidget, widget_elem.text)
+
+            if lastwidget is not None:
+                self.toplevelWidget.setTabOrder(lastwidget, widget)
+
             lastwidget = widget
 
     def readResources(self, elem):
