@@ -602,7 +602,11 @@ bool Chimera::fromPyObject(PyObject *py, void *cpp) const
         }
 
     case QMetaType::QVariantMap:
+#if PY_VERSION_HEX >= 0x02040000
+        if (PyDict_CheckExact(py))
+#else
         if (PyDict_Check(py))
+#endif
         {
             QVariantMap qm;
 
@@ -624,7 +628,11 @@ bool Chimera::fromPyObject(PyObject *py, void *cpp) const
 
 #if QT_VERSION >= 0x040500
     case QMetaType::QVariantHash:
+#if PY_VERSION_HEX >= 0x02040000
+        if (PyDict_CheckExact(py))
+#else
         if (PyDict_Check(py))
+#endif
         {
             QVariantHash qh;
 
@@ -728,7 +736,7 @@ QVariant Chimera::fromPyObject(PyObject *py) const
 {
     // Deal with the simple case of wrapping the Python object rather than
     // converting it.
-    if (_metatype == PyQt_PyObject::metatype)
+    if (_type != sipType_QVariant && _metatype == PyQt_PyObject::metatype)
     {
         return keep_as_pyobject(py);
     }
@@ -926,7 +934,11 @@ QVariant Chimera::fromPyObject(PyObject *py) const
         }
 
     case QMetaType::QVariantMap:
+#if PY_VERSION_HEX >= 0x02040000
+        if (PyDict_CheckExact(py))
+#else
         if (PyDict_Check(py))
+#endif
         {
             QVariantMap qm;
 
@@ -956,7 +968,11 @@ QVariant Chimera::fromPyObject(PyObject *py) const
 
 #if QT_VERSION >= 0x040500
     case QMetaType::QVariantHash:
+#if PY_VERSION_HEX >= 0x02040000
+        if (PyDict_CheckExact(py))
+#else
         if (PyDict_Check(py))
+#endif
         {
             QVariantHash qh;
 
@@ -1007,6 +1023,10 @@ QVariant Chimera::fromPyObject(PyObject *py) const
                 "unable to convert a Python '%s' object to a C++ '%s' instance",
                 Py_TYPE(py)->tp_name, _name.constData());
     }
+    else if (_type == sipType_QVariant)
+    {
+        variant = QVariant(*reinterpret_cast<QVariant *>(variant_data));
+    }
     else if (metatype_used != QMetaType::Void)
     {
         variant = QVariant(metatype_used, variant_data);
@@ -1023,15 +1043,22 @@ QVariant Chimera::fromPyObject(PyObject *py) const
 
 // Convert a Python object to a QVariant (which will be invalid if there was an
 // error) based on the type of the object.
-QVariant Chimera::fromAnyPyObject(PyObject *py)
+QVariant Chimera::fromAnyPyObject(PyObject *py, int *is_err)
 {
     QVariant variant;
-    Chimera *ct = new Chimera;
 
-    if (ct->parse_py_type(Py_TYPE(py), true))
-        variant = ct->fromPyObject(py);
+    if (py != Py_None)
+    {
+        Chimera *ct = new Chimera;
 
-    delete ct;
+        if (ct->parse_py_type(Py_TYPE(py), true))
+            variant = ct->fromPyObject(py);
+
+        if (!variant.isValid())
+            *is_err = 1;
+
+        delete ct;
+    }
 
     return variant;
 }
@@ -1040,25 +1067,28 @@ QVariant Chimera::fromAnyPyObject(PyObject *py)
 // Convert a QVariant to Python.
 PyObject *Chimera::toPyObject(const QVariant &var) const
 {
-    // A sanity check.
-    if (_metatype != var.userType())
+    if (_type != sipType_QVariant)
     {
-        PyErr_Format(PyExc_TypeError,
-                "unable to convert a QVariant of type %d to a QMetaType of type %d",
-                _metatype, var.userType());
+        // A sanity check.
+        if (_metatype != var.userType())
+        {
+            PyErr_Format(PyExc_TypeError,
+                    "unable to convert a QVariant of type %d to a QMetaType of type %d",
+                    _metatype, var.userType());
 
-        return 0;
-    }
+            return 0;
+        }
 
-    // Deal with the simple case of unwrapping a Python object rather than
-    // converting it.
-    if (_metatype == PyQt_PyObject::metatype)
-    {
-        PyQt_PyObject pyobj_wrapper = qVariantValue<PyQt_PyObject>(var);
+        // Deal with the simple case of unwrapping a Python object rather than
+        // converting it.
+        if (_type != sipType_QVariant && _metatype == PyQt_PyObject::metatype)
+        {
+            PyQt_PyObject pyobj_wrapper = qVariantValue<PyQt_PyObject>(var);
 
-        Py_XINCREF(pyobj_wrapper.pyobject);
+            Py_XINCREF(pyobj_wrapper.pyobject);
 
-        return pyobj_wrapper.pyobject;
+            return pyobj_wrapper.pyobject;
+        }
     }
 
     return toPyObject(const_cast<void *>(var.data()));
@@ -1173,25 +1203,21 @@ PyObject *Chimera::toPyObject(void *cpp) const
 
     case QMetaType::QVariantList:
         {
-            QVariantList ql = reinterpret_cast<QVariant *>(cpp)->toList();
+            QVariantList *ql = reinterpret_cast<QVariantList *>(cpp);
 
-            py = PyList_New(ql.size());
+            py = PyList_New(ql->size());
 
             if (py)
             {
-                for (int i = 0; i < ql.size(); ++i)
+                for (int i = 0; i < ql->size(); ++i)
                 {
-                    QVariant *val = new QVariant(ql.at(i));
-                    PyObject *val_obj = sipConvertFromNewType(val,
-                            sipType_QVariant, 0);
+                    PyObject *val_obj = toAnyPyObject(ql->at(i));
 
                     if (!val_obj)
                     {
                         Py_DECREF(py);
                         py = 0;
 
-                        delete val;
-
                         break;
                     }
 
@@ -1204,12 +1230,13 @@ PyObject *Chimera::toPyObject(void *cpp) const
 
     case QMetaType::QVariantMap:
         {
-            QVariantMap qm = reinterpret_cast<QVariant *>(cpp)->toMap();
-
             py = PyDict_New();
 
             if (py)
-                for (QVariantMap::const_iterator it = qm.constBegin(); it != qm.constEnd(); ++it)
+            {
+                QVariantMap *qm = reinterpret_cast<QVariantMap *>(cpp);
+
+                for (QVariantMap::const_iterator it = qm->constBegin(); it != qm->constEnd(); ++it)
                     if (!add_variant_to_dict(py, it.key(), it.value()))
                     {
                         Py_DECREF(py);
@@ -1217,6 +1244,7 @@ PyObject *Chimera::toPyObject(void *cpp) const
 
                         break;
                     }
+            }
 
             break;
         }
@@ -1224,12 +1252,13 @@ PyObject *Chimera::toPyObject(void *cpp) const
 #if QT_VERSION >= 0x040500
     case QMetaType::QVariantHash:
         {
-            QVariantHash qh = reinterpret_cast<QVariant *>(cpp)->toHash();
-
             py = PyDict_New();
 
             if (py)
-                for (QVariantHash::const_iterator it = qh.constBegin(); it != qh.constEnd(); ++it)
+            {
+                QVariantHash *qh = reinterpret_cast<QVariantHash *>(cpp);
+
+                for (QVariantHash::const_iterator it = qh->constBegin(); it != qh->constEnd(); ++it)
                     if (!add_variant_to_dict(py, it.key(), it.value()))
                     {
                         Py_DECREF(py);
@@ -1237,6 +1266,7 @@ PyObject *Chimera::toPyObject(void *cpp) const
 
                         break;
                     }
+            }
 
             break;
         }
@@ -1271,8 +1301,7 @@ bool Chimera::add_variant_to_dict(PyObject *dict, const QString &key_ref,
     QString *key = new QString(key_ref);
     PyObject *key_obj = sipConvertFromNewType(key, sipType_QString, 0);
 
-    QVariant *val = new QVariant(val_ref);
-    PyObject *val_obj = sipConvertFromNewType(val, sipType_QVariant, 0);
+    PyObject *val_obj = toAnyPyObject(val_ref);
 
     if (!key_obj || !val_obj || PyDict_SetItem(dict, key_obj, val_obj) < 0)
     {
@@ -1281,10 +1310,7 @@ bool Chimera::add_variant_to_dict(PyObject *dict, const QString &key_ref,
         else
             delete key;
 
-        if (val_obj)
-            Py_DECREF(val_obj);
-        else
-            delete val;
+        Py_XDECREF(val_obj);
 
         return false;
     }
@@ -1301,10 +1327,8 @@ PyObject *Chimera::toAnyPyObject(const QVariant &var)
 {
     if (!var.isValid())
     {
-        PyErr_SetString(PyExc_TypeError,
-                "unable to convert an invalid QVariant to a Python object");
-
-        return 0;
+        Py_INCREF(Py_None);
+        return Py_None;
     }
 
     const char *type_name = var.typeName();
