@@ -35,7 +35,6 @@
 
 #include <Python.h>
 
-#include <QtGlobal>
 #include <QByteArray>
 #include <QList>
 #include <QMap>
@@ -177,26 +176,29 @@ static int create_dynamic_metaobject(pyqtWrapperType *pyqt_wt)
 
         if (sig_obj)
         {
-            Q_ASSERT(PyList_Check(sig_obj));
-
-            for (SIP_SSIZE_T i = 0; i < PyList_GET_SIZE(sig_obj); ++i)
+            // Make sure it is a list and not some legitimate attribute that
+            // happens to use our special name.
+            if (PyList_Check(sig_obj))
             {
-                qpycore_slot slot;
+                for (SIP_SSIZE_T i = 0; i < PyList_GET_SIZE(sig_obj); ++i)
+                {
+                    qpycore_slot slot;
 
-                // Set up the skeleton slot.
-                PyObject *decoration = PyList_GET_ITEM(sig_obj, i);
-                slot.signature = Chimera::Signature::fromPyObject(decoration);
+                    // Set up the skeleton slot.
+                    PyObject *decoration = PyList_GET_ITEM(sig_obj, i);
+                    slot.signature = Chimera::Signature::fromPyObject(decoration);
 
-                slot.sip_slot.pyobj = 0;
-                slot.sip_slot.name = 0;
-                slot.sip_slot.meth.mfunc = value;
-                slot.sip_slot.meth.mself = 0;
+                    slot.sip_slot.pyobj = 0;
+                    slot.sip_slot.name = 0;
+                    slot.sip_slot.meth.mfunc = value;
+                    slot.sip_slot.meth.mself = 0;
 #if PY_MAJOR_VERSION < 3
-                slot.sip_slot.meth.mclass = (PyObject *)pyqt_wt;
+                    slot.sip_slot.meth.mclass = (PyObject *)pyqt_wt;
 #endif
-                slot.sip_slot.weakSlot = 0;
+                    slot.sip_slot.weakSlot = 0;
 
-                qo->pslots.append(slot);
+                    qo->pslots.append(slot);
+                }
             }
 
             Py_DECREF(sig_obj);
